@@ -5,10 +5,4 @@ from __future__ import unicode_literals, absolute_import
 
 from .icalendar import Calendar
 from .event import Event
-
-
-__title__ = 'ics'
-__version__ = '0.1.1'
-__author__ = 'Nikita Marchant'
-__license__ = 'Apache License, Version 2.0'
-__copyright__ = 'Copyright 2013 Nikita Marchant'
+from .__meta__ import __title__, __version__, __author__, __license__, __copyright__
